@@ -125,7 +125,11 @@ class ConfigInterface:
 
         if name not in self.data["components"]:
             raise ValueError(
-                f"Component '{name}' not found. Is it registered in the machinable.yaml?"
+                f"Component '{name}' not found. Is it registered in the machinable.yaml?\n"
+                "Registered components:\n\t- "
+                + "\n\t- ".join(
+                    filter(lambda x: x != "@", self.data["components"].keys())
+                )
             )
 
         if self.default_class is not None:
@@ -138,7 +142,7 @@ class ConfigInterface:
         config = copy.deepcopy(self.data["components"][name])
 
         # flags
-        config["flags"] = flags if flags is not None else {}
+        config["flags"] = update_dict(config["flags"], flags)
 
         # name
         config["name"] = name
@@ -226,7 +230,11 @@ class ConfigInterface:
                         )
                     except KeyError:
                         raise KeyError(
-                            f"Mixin '{mixin['name']}' not found. Is it registered under 'mixins'?"
+                            f"Mixin '{mixin['name']}' not found. Is it registered in the machinable.yaml?\n"
+                            "Registered mixins:\n\t- "
+                            + "\n\t- ".join(
+                                filter(lambda x: x != "@", self.data["mixins"].keys())
+                            )
                         )
 
             # the mixin config can be overwritten by the local config so we update the mixin arg and write it back
@@ -254,6 +262,8 @@ class ConfigInterface:
                 update = (update,)
 
             for k in update:
+                if k is None:
+                    continue
                 # load arguments from machinable.yaml
                 if isinstance(k, str):
                     config["versions"].append(k)
@@ -277,7 +287,7 @@ class ConfigInterface:
 
         # remove unused versions
         config["args"] = {
-            k: v
+            k: v if not k.startswith("~") else "_"
             for k, v in config["args"].items()
             if not k.startswith("~") or k in config["versions"]
         }
