@@ -3,7 +3,10 @@ import os
 import click
 
 from ..execution.execution import Execution
+from ..experiment import Experiment
 from ..filesystem import parse_storage_url
+from ..utils.formatting import exception_to_str, msg
+from ..utils.importing import resolve_instance_from_code
 
 
 @click.command()
@@ -20,6 +23,26 @@ def execute(experiment, storage, engine, project, seed):
     """
     Executes an EXPERIMENT
     """
+    if experiment.startswith(":"):
+        code = "from machinable import Experiment\n\nExperiment()"
+        if os.path.isfile(experiment[1:]):
+            with open(experiment[1:], "r") as f:
+                code = f.read()
+        code = "# save empty to abort\n\n" + code
+
+        c = True
+        while c:
+            code = click.edit(code, extension=".py")
+            if code == "":
+                print("Empty experiment. Aborting.")
+                return
+            try:
+                experiment = resolve_instance_from_code(code, Experiment)
+                c = False
+            except ImportError as e:
+                msg(exception_to_str(e), color="fail")
+                click.confirm("Continue editing?", abort=True)
+
     try:
         seed = int(seed)
     except (ValueError, TypeError):
@@ -59,7 +82,7 @@ def execution(url, storage, engine, project, checkpoint, version, seed):
 
         execution = Execution.from_storage(url)
 
-    if version == "&":
+    if version == ":":
         version = click.edit("{}", extension=".py")
 
     if seed is not None:
