@@ -1,4 +1,5 @@
 import ast
+import copy
 import inspect
 import os
 from datetime import datetime as dt
@@ -23,6 +24,7 @@ from ..project.export import Export
 from ..registration import Registration
 from ..storage import Storage
 from ..storage.experiment import StorageExperiment
+from ..utils.utils import sentinel
 from ..utils.dicts import merge_dict, update_dict
 from ..utils.formatting import exception_to_str, msg
 from ..utils.host import get_host_info
@@ -41,18 +43,31 @@ def to_color(experiment_id):
     )
 
 
+def _code_backup_settings(value):
+    enabled = None
+    exclude = None
+    if value in [True, False, None]:
+        enabled = value
+    if isinstance(value, dict):
+        enabled = value.get("enabled", None)
+        exclude = value.get("exclude", None)
+    if isinstance(exclude, tuple):
+        exclude = list(exclude)
+    return {"enabled": enabled, "exclude": exclude}
+
+
 _latest = [None]
 
 
 class Execution(Jsonable):
     def __init__(
         self,
-        experiment: Union[Experiment, Any],
-        storage: Union[dict, str] = None,
+        experiment: Union[Experiment, Callable, Any, None] = sentinel,
+        storage: Union[dict, str, None] = None,
         engine: Union[Engine, str, dict, None] = None,
         index: Union[Index, str, dict, None] = None,
-        project: Union[Project, Callable, str, dict] = None,
-        seed: Union[int, None, str] = None,
+        project: Union[Project, Callable, str, dict, None] = None,
+        seed: Union[int, str, None] = None,
     ):
         self.function = None
 
@@ -81,7 +96,12 @@ class Execution(Jsonable):
             self.function = experiment
             return
 
+        # this may extend the PYTHONPATH and must thus be called before any import-dependent methods below
         self.set_project(project)
+
+        # preload the registration that may be used to register engines etc.
+        Registration.get()
+
         self.set_storage(storage)
         self.set_experiment(experiment)
         self.set_engine(engine)
@@ -134,6 +154,10 @@ class Execution(Jsonable):
         raise ValueError(f"Invalid argument: {args}")
 
     def set_experiment(self, experiment):
+        if experiment is sentinel:
+            self.experiment = None
+            return self
+
         self.experiment = Experiment.create(experiment)
 
         return self
@@ -252,6 +276,11 @@ class Execution(Jsonable):
 
         return self
 
+    def set_code_backup(self, enabled=None, exclude=None):
+        self.code_backup = {"enabled": enabled, "exclude": exclude}
+
+        return self
+
     def set_checkpoint(self, checkpoint):
         def transformation(i, component, element):
             element[1]["flags"]["CHECKPOINT"] = checkpoint
@@ -372,12 +401,33 @@ class Execution(Jsonable):
             self.engine.on_before_storage_creation(self)
             Registration.get().on_before_storage_creation(self)
 
+            # determine code backup settings
+            code_backup = _code_backup_settings(self.code_backup)
+
+            # use project settings by default
+            _project_settings = _code_backup_settings(
+                Registration.get().default_code_backup(execution=self)
+            )
+
+            if code_backup["enabled"] is None:
+                code_backup["enabled"] = _project_settings["enabled"]
+            if code_backup["exclude"] is None:
+                code_backup["exclude"] = _project_settings["exclude"]
+
+            # otherwise fall back on system-wide settings
+            _user_settings = _code_backup_settings(
+                get_settings()["default_code_backup"]
+            )
+            if code_backup["enabled"] is None:
+                _user_settings["enabled"] = _user_settings["enabled"]
+            if code_backup["exclude"] is None:
+                code_backup["exclude"] = _user_settings["exclude"]
+
             # do not backup on mem:// filesystem unless explicitly set to True
-            code_backup = self.code_backup
-            if code_backup is None and not self.storage.config["url"].startswith(
-                "mem://"
-            ):
-                code_backup = True
+            if code_backup["enabled"] is None and not self.storage.config[
+                "url"
+            ].startswith("mem://"):
+                code_backup["enabled"] = True
 
             # collect and write execution data
             url = self.storage.get_url()
@@ -402,8 +452,10 @@ class Execution(Jsonable):
             }
 
             with open_fs({"url": url, "create": True}) as filesystem:
-                if code_backup:
-                    self.project.backup_source_code(opener=filesystem.open)
+                if code_backup["enabled"]:
+                    self.project.backup_source_code(
+                        opener=filesystem.open, exclude=code_backup["exclude"]
+                    )
 
                 for k, v in data.items():
                     filesystem.save_file(name=k, data=v)
@@ -626,10 +678,20 @@ class Execution(Jsonable):
                     "MODULE",
                 }
             }
+            if filtered.get("OUTPUT_REDIRECTION", "SYS_AND_FILE") == "SYS_AND_FILE":
+                filtered.pop("OUTPUT_REDIRECTION", None)
             if len(filtered) == 0:
                 return ""
             return yaml.dump(filtered, default_flow_style=False)
 
+        def _args(config):
+            config = copy.deepcopy(config)
+            if config.get("_evaluate", True) is True:
+                config.pop("_evaluate", None)
+            if len(config) == {}:
+                return "-"
+            return yaml.dump(config, default_flow_style=False)
+
         for (
             index,
             (execution_type, component, components, resources, args, kwargs),
@@ -652,7 +714,7 @@ class Execution(Jsonable):
             if len(component["versions"]) > 0:
                 msg(f">> {', '.join(component['versions'])}", color="green")
             msg(_flags(component["flags"]))
-            msg(yaml.dump(component["args"], default_flow_style=False), color="blue")
+            msg(_args(component["args"]), color="blue")
 
             for c in components:
                 if c:
@@ -660,9 +722,7 @@ class Execution(Jsonable):
                     if len(c["versions"]) > 0:
                         msg(f"\t>> {', '.join(c['versions'])}", color="green")
                     msg(_flags(c["flags"]))
-                    msg(
-                        yaml.dump(c["args"], default_flow_style=False), color="blue",
-                    )
+                    msg(_args(c["args"]), color="blue")
 
         msg("------\n", color="header")
 
