@@ -1,6 +1,7 @@
 import os
 from typing import Union
 
+import jsonlines
 import pendulum
 
 from ..config.mapping import config_map
@@ -8,16 +9,14 @@ from ..filesystem import open_fs, parse_storage_url
 from ..storage.models import StorageComponentModel
 from ..utils.utils import sentinel
 from .collections import RecordCollection
-from .models.filesystem import StorageComponentFileSystemModel
+from .views.views import get as get_view
 
 
 class StorageComponent:
     def __init__(
         self, url: Union[str, dict, StorageComponentModel], experiment=None, cache=None
     ):
-        self._model = StorageComponentModel.create(
-            url, template=StorageComponentFileSystemModel
-        )
+        self._model = StorageComponentModel.create(url)
         self._cache = cache or {}
         self._cache["experiment"] = experiment
 
@@ -26,7 +25,9 @@ class StorageComponent:
 
         # Arguments
         filepath: Relative filepath
-        reload: If True, cache will be ignored. If datetime, file will be reloaded if cached version is older than the date
+        default: Optional default if file does not exist
+        reload: If True, cache will be ignored. If datetime, file will be reloaded
+                if cached version is older than the date
         """
         if reload is None:
             finished_at = self.finished_at
@@ -47,16 +48,15 @@ class StorageComponent:
                 reload = True
 
         if filepath not in self._cache or reload:
-            with open_fs(self.url) as filesystem:
-                try:
-                    self._cache[filepath] = filesystem.load_file(filepath)
-                    if filepath not in self._cache["_files"]:
-                        self._cache["_files"][filepath] = {}
-                    self._cache["_files"][filepath]["loaded_at"] = pendulum.now()
-                except FileNotFoundError:
-                    if default is not sentinel:
-                        return default
-                    raise
+            try:
+                self._cache[filepath] = self._model.file(filepath)
+                if filepath not in self._cache["_files"]:
+                    self._cache["_files"][filepath] = {}
+                self._cache["_files"][filepath]["loaded_at"] = pendulum.now()
+            except FileNotFoundError:
+                if default is not sentinel:
+                    return default
+                raise
 
         return self._cache[filepath]
 
@@ -93,35 +93,17 @@ class StorageComponent:
 
         return self._cache["experiment"]
 
-    def store(self, name=None):
-        """Retrieves element from the store
-
-        This is the counterpart to the ``store.write`` method.
+    def data(self, name=None, default=sentinel):
+        """Retrieves a data object from the storage
 
         # Arguments
-        name: Key or filename of the object that is to be retrieved. If None, a list of available objects is returned
+        name: Name of the data object. If None, a list of available objects is returned
         """
-        if isinstance(name, str) and os.path.splitext(name)[1] != "":
-            return self._model.file(os.path.join("store", name))
-
-        if "store" in self._cache:
-            store = self._cache["store"]
-        else:
-            try:
-                store = self._model.file("store.json")
-            except FileNotFoundError:
-                store = {}
-
-            with open_fs(self.url) as filesystem:
-                store["__files"] = filesystem.listdir("store")
-
-            if self.is_finished():
-                self._cache["store"] = store
-
         if name is None:
-            return store
+            with open_fs(self.url) as filesystem:
+                return filesystem.listdir("data")
 
-        return store[name]
+        return self.file(os.path.join("data", name), default)
 
     @property
     def config(self):
@@ -202,7 +184,7 @@ class StorageComponent:
     def has_records(self, scope="default"):
         """Returns True if records of given scope exist"""
         with open_fs(self.url) as filesystem:
-            return filesystem.exists(f"records/{scope}.json")
+            return filesystem.exists(f"records/{scope}.jsonl")
 
     def get_records(self, scope=None):
         """Returns a record collection
@@ -216,14 +198,26 @@ class StorageComponent:
             try:
                 with open_fs(self.url) as filesystem:
                     scopes = filesystem.listdir("records")
-                    return [s[:-5] for s in scopes if s.endswith(".json")]
+                    return [s[:-6] for s in scopes if s.endswith(".jsonl")]
             except FileNotFoundError:
                 return []
 
         if "records." + scope in self._cache:
             return self._cache["records." + scope]
 
-        records = RecordCollection(self.file(f"records/{scope}.p"))
+        records = []
+        try:
+            with open_fs(self.url) as filesystem:
+                if filesystem.isfile(f"records/{scope}.jsonl"):
+                    with jsonlines.Reader(
+                        filesystem.open(f"records/{scope}.jsonl")
+                    ) as reader:
+                        for record in reader.iter():
+                            # schema
+                            records.append(record)
+        except FileNotFoundError:
+            pass
+        records = RecordCollection(records)
 
         if self.is_finished():
             self._cache["records." + scope] = records
@@ -286,6 +280,33 @@ class StorageComponent:
         """Shorthand for is_started() and not (is_active() or is_finished())"""
         return self.is_started() and not (self.is_active() or self.is_finished())
 
+    @property
+    def view(self):
+        """Returns the registered view"""
+        return get_view("component", self)
+
+    def __getattr__(self, item):
+        if item.startswith("_") and item.endswith("_"):
+            view = get_view("component", self, name=item)
+            if view is not None:
+                return view
+
+        raise AttributeError(
+            f"{self.__class__.__name__} object has no attribute {item}"
+        )
+
+    def serialize(self):
+        return {
+            "experiment_id": self.experiment.experiment_id,
+            "experiment_name": self.experiment.experiment_name,
+            "project_name": self.experiment.project_name,
+            "component_id": self.component_id,
+            "component": self,
+            "started_at": self.started_at,
+            "heartbeat_at": self.heartbeat_at,
+            "finished_at": self.finished_at,
+        }
+
     def __str__(self):
         return self.__repr__()
 
