@@ -4,5 +4,6 @@ from machinable.index.sql_index import SqlIndex
 
 
 def test_index_instantiation():
-    assert isinstance(Index(), NativeIndex)
+    assert isinstance(Index(), SqlIndex)
+    assert isinstance(NativeIndex(), NativeIndex)
     assert isinstance(SqlIndex(), SqlIndex)
