@@ -1,3 +1,4 @@
+import math
 import os
 
 import numpy as np
@@ -22,8 +23,8 @@ def test_storage_interface():
     assert storage.get_url() == "osfs://" + get_path("tttttt/")
     assert storage.get_local_directory() == get_path("tttttt/")
     assert storage.get_path() == "tttttt/"
-    assert storage.get_component() is None
-    c = storage.get_experiment().components.first()
+    assert storage.get_component(index=False) is None
+    c = storage.get_component()
     storage = Storage(
         url=STORAGE_DIRECTORY, experiment="tttttt", component=c.component_id
     )
@@ -88,6 +89,23 @@ def test_storage_component():
     custom = comp.get_records("validation")
     assert custom.sum("iteration") == 15
     assert records.as_dataframe().size > 0
+    assert len(comp.file("output.log")) > 0
+    assert len(comp.file("log.txt")) > 0
 
     comp = get_experiment(get_path("subdirectory/TTTTTT"))
     assert comp.components.first().experiment.experiment_id == "TTTTTT"
+
+
+def test_storage_component_records():
+    records = get_experiment(get_path("tttttt")).components.first().records
+    record = records.first()
+
+    assert isinstance(record["_timestamp"], (float, int))
+    assert isinstance(record["number"], int)
+    assert record["constant"] == 42
+    assert isinstance(record["float"], float)
+    assert isinstance(record["string"], str)
+    assert record["none"] is None
+    assert math.isnan(record["nan"])
+    assert isinstance(record["custom"], dict)
+    assert isinstance(record["date"], str)
