@@ -1,12 +1,17 @@
+from nodes.default_fallback import DefaultFallback
+
 from machinable.engine import Slurm
 from machinable.registration import Registration
-from nodes.default_fallback import DefaultFallback
 
 
 class Project(Registration):
     def config_global_conf(self, works=False):
         return works
 
+    @staticmethod
+    def host_test_info_static():
+        return "static_test_info"
+
     def host_test_info(self):
         return "test_info"
 
